@@ -95,10 +95,10 @@ def training_callback(base_cfg, data_config):
     cfg=Config()
     train(cfg)
 
-def make_training_app():
+def make_training_app(function=training_callback,columns=[3, 3]):
     base_config=get_base_config()
     data_config=get_data_config()
-    app = make_app(function=training_callback, args=(base_config, data_config), columns=[4, 3])
+    app = make_app(function=function, args=(base_config, data_config), columns=columns)
     return app
 
 
